#include "articleparser.h"
#include <QDebug>
#include <QStringList>

ArticleParser::ArticleParser(QObject *parent) :
    QObject(parent)
{
}

QString ArticleParser::parseArticleContent(QString article)
{


  //  article.remove(QRegExp("\\<table[^\\>]+\\>"));
    //remove tables
    while (article.contains(QRegExp("\\<table[^\\>]+\\>")))
    {
        int start = article.indexOf(QRegExp("\\<table[^\\>]+\\>"));
        int end = article.indexOf(QRegExp("\\</table\\>"));
        if (article.indexOf(QRegExp("\\</table\\>")) <=  article.indexOf(QRegExp("\\<table[^\\>]+\\>")))
            break;
        int length = end - start + 8;
        article.remove(article.indexOf(QRegExp("\\<table[^\\>]+\\>")), length );
    }

   // article.indexOf(QRegExp("\\<table[^\\>]+\\>")
    //remove html tags
    article.replace( QRegExp("<[^>]*>"), " " );
    //remove references and edit blocks
    article.replace( QRegExp("\\[([^\\]])+\\]"), "" );
   // TODO MORE OFTHIS HERE PARSIN AND STUFF

    if (article.contains("External links"))
    {
        article.remove(article.lastIndexOf("External links"), article.count());
    }
    if (article.contains("References"))
    {
        article.remove(article.lastIndexOf("References"), article.count());
    }
    return article;
}
